@@ -1,8 +1,9 @@
 import numpy as np
 import sympy as sp
 
-import lbmpy.plot as plt
 import pystencils as ps
+from pystencils import make_slice, show_code
+from pystencils.jupyter import *
 from lbmpy.advanced_streaming import *
 from lbmpy.boundaries import *
 from lbmpy.creationfunctions import *
@@ -11,8 +12,7 @@ from lbmpy.geometry import *
 from lbmpy.lbstep import LatticeBoltzmannStep
 from lbmpy.macroscopic_value_kernels import pdf_initialization_assignments
 from lbmpy.parameterization import ScalingWidget
+import lbmpy.plot as plt
 from lbmpy.postprocessing import *
 from lbmpy.scenarios import *
-from lbmpy.stencils import get_stencil, LBStencil
-from pystencils import make_slice, show_code
-from pystencils.jupyter import *
+from lbmpy.stencils import LBStencil
